package javax.swing;

import javax.accessibility.AccessibleRole;
import javax.accessibility.AccessibleContext;
import java.io.IOException;
import java.io.ObjectOutputStream;
import javax.swing.plaf.ButtonUI;
import javax.accessibility.Accessible;

public class JRadioButton extends JToggleButton implements Accessible
{
    private static final String uiClassID = "RadioButtonUI";
    
    public JRadioButton() {
        this(null, null, false);
    }
    
    public JRadioButton(Icon icon) {
        this(null, icon, false);
    }
    
    public JRadioButton(Action action) {
        this();
        this.setAction(action);
    }
    
    public JRadioButton(Icon icon, boolean b) {
        this(null, icon, b);
    }
    
    public JRadioButton(String s) {
        this(s, null, false);
    }
    
    public JRadioButton(String s, boolean b) {
        this(s, null, b);
    }
    
    public JRadioButton(String s, Icon icon) {
        this(s, icon, false);
    }
    
    public JRadioButton(String s, Icon icon, boolean b) {
        super(s, icon, b);
        this.setBorderPainted(false);
        this.setHorizontalAlignment(10);
    }
    
    @Override
    public void updateUI() {
        this.setUI((ButtonUI)UIManager.getUI(this));
    }
    
    @Override
    public String getUIClassID() {
        return "RadioButtonUI";
    }
    
    @Override
    void setIconFromAction(Action action) {
    }
    
    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        objectOutputStream.defaultWriteObject();
        if (this.getUIClassID().equals("RadioButtonUI")) {
            int n = (byte)(JComponent.getWriteObjCounter(this) - 1);
            JComponent.setWriteObjCounter(this, (byte)n);
            if (n == 0 && this.ui != null) {
                this.ui.installUI(this);
            }
        }
    }
    
    @Override
    protected String paramString() {
        return super.paramString();
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new JRadioButton.AccessibleJRadioButton();
        }
        return this.accessibleContext;
    }
    
    protected class AccessibleJRadioButton extends JToggleButton.AccessibleJToggleButton
    {
        @Override
        public AccessibleRole getAccessibleRole() {
            return AccessibleRole.RADIO_BUTTON;
        }
    }
}
